@@ -138,7 +138,7 @@ bitflags! {
     }
 }
 
-#[derive(Debug, Clone, Copy, FromPrimitive, Eq, PartialEq)]
+#[derive(Debug, Clone, Copy, FromPrimitive, Eq, PartialEq, Hash)]
 #[repr(u32)]
 pub enum FileType {
     Socket = 0o140000,
@@ -154,7 +154,7 @@ pub enum FileType {
 ///
 /// UnixTimeStamp stores number of seconds elapsed since 1970-01-01 00:00:00 UTC
 /// as `u32`.
-#[derive(Debug, Default, Copy, Clone, PartialEq, Eq)]
+#[derive(Debug, Default, Copy, Clone, PartialEq, Eq, Hash)]
 pub struct UnixTimeStamp(u32);
 
 #[derive(Debug, thiserror::Error)]
